<?php
// Own namespace
namespace CoreFramework\Controller;

// Import framework stuff
use CoreFramework\Controller\BaseController;
use CoreFramework\Controller\Controller;
use CoreFramework\Factory\ObjectFactory;
use CoreFramework\Request\Requestable;
use CoreFramework\Resolver\Command\CommandResolver;
use CoreFramework\Response\Responseable;

/**
 * The default controller with news for e.g. home or news page
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class ConsoleDefaultNewsController extends BaseController implements Controller {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @param	$resolverInstance		An instance of a command resolver class
	 * @return	$controllerInstance		A prepared instance of this class
	 */
	public static final function createConsoleDefaultNewsController (CommandResolver $resolverInstance) {
		// Create the instance
		$controllerInstance = new ConsoleDefaultNewsController();

		// Set the command resolver
		$controllerInstance->setResolverInstance($resolverInstance);

		// Add news filters to this controller
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('news_download_filter_class'));
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('news_process_filter_class'));

		// Return the prepared instance
		return $controllerInstance;
	}

	/**
	 * Handles the given request and response
	 *
	 * @param	$requestInstance	An instance of a Requestable class
	 * @param	$responseInstance	An instance of a Responseable class
	 * @return	void
	 */
	public function handleRequest (Requestable $requestInstance, Responseable $responseInstance) {
		// Generic pre-post command execution
		$this->executeGenericPrePostCommand($requestInstance, $responseInstance);
	}

}
