<?php
// Own namespace
namespace CoreFramework\State;

// Import framework stuff
use CoreFramework\Generic\UnsupportedOperationException;
use CoreFramework\Object\BaseFrameworkSystem;

/**
 * A general state class
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class BaseState extends BaseFrameworkSystem implements Stateable {
	// Exception code constants
	const EXCEPTION_INVALID_STATE = 0xc00;

	/**
	 * State name for printing out (except debug output where you want to use
	 * $stateInstance->__toString() instead of this).
	 */
	private $stateName = '';

	/**
	 * Protected constructor
	 *
	 * @param	$className	Name of the class
	 * @return	void
	 */
	protected function __construct ($className) {
		// Call parent constructor
		parent::__construct($className);
	}

	/**
	 * Getter for state name
	 *
	 * @return	$stateName	Name of this state in a printable maner
	 */
	public final function getStateName () {
		return $this->stateName;
	}

	/**
	 * Setter for state name
	 *
	 * @param	$stateName	Name of this state in a printable maner
	 * @return	void
	 */
	protected final function setStateName ($stateName) {
		$this->stateName = $stateName;
	}

	/**
	 * Executes the state with given Executor instance
	 *
	 * @param	$executorInstance	An instance of a Executor class
	 * @return	void
	 * @throws	UnsupportedOperationException	This method should be overwritten
	 */
	public function executeState (Executor $executorInstance) {
		throw new UnsupportedOperationException(array($this, __FUNCTION__, $executorInstance), self::EXCEPTION_UNSPPORTED_OPERATION);
	}

}
